function obj=randiher(Imax,N,d,varargin)
% FUNCTION fc_amat.random.randiher
% -- randiher(Imax,N,d,varargin) 
%      Returns a N-by-d-by-d amat object whose matrices are hermitian where
%      real part values are drawn from the discrete uniform distribution on 
%      1:Imax and imaginary part values are drawn from the discrete uniform 
%      distribution on 1:Imax times a random sign.
%
% -- randiher([Imin,Imax],N,d,varargin) 
%      Returns a N-by-d-by-d amat object whose matrices are hermitian where
%      real part values are drawn from the discrete uniform distribution on 
%      Imin:Imax and imaginary part values are drawn from the discrete uniform 
%      distribution on Imin:Imax times a random sign.
%
%
%      Optional key/value pairs arguments are available with keys:
%        - 'class', value can be 'single' or 'double' (default).
%
%      See also: fc_amat.random.randnher, fc_amat.random.randher
%                class amat, randi
%
  p = inputParser; 
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'})); 
  % No integers! conj error:'Complex integers are not supported.'
  p.parse(varargin{:});
  classname=p.Results.class;
  
%    assert( classname(1) ~= 'u', 'Unsigned classname not allowed!')
%    if ismember(lower(classname),{'single','double'});
%      Conj=@(x) conj(x);
%    else
%      Conj=eval(sprintf('@(x) %s(conj(double(x)));',classname));
%    end
  obj=amat(N,d,d,classname);
  s=@() -3+2*randi(2,N,1,classname); % sign; 

  for i=1:d
    obj(i,i)=complex(randi(Imax,N,1,classname),s().*randi(Imax,N,1,classname));
    for j=i+1:d
      obj(i,j)=complex(randi(Imax,N,1,classname),s().*randi(Imax,N,1,classname));
      obj(j,i)=conj(obj(i,j));
    end
  end
end
