function varargout=sliceiso(q,me,u,P,varargin)
  % plot function u on plane defined by p(1)*x+p(2)*y+p(3)*z+p(4)=0
  [dim,d,nq,nme]=fc_meshtools.simplicial.get_dims(q,me);
  assert(d==3 && dim==3)
  U=fc_meshtools.eval(u,q);
  p = inputParser;
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('niso',10,@isscalar);
  p.addParamValue('color',[]); % unique color
  p.addParamValue('isorange',[]);
  p.addParamValue('isocolorbar',false,@islogical);
  p.addParamValue('format','%g',@ischar);
  p.addParamValue('mouse',true,@islogical);
  p.parse(varargin{:});
  R=p.Results;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  if (isempty(R.isorange) && R.niso>1), R.isorange=linspace(min(u),max(u),R.niso);end
  isorange=R.isorange;niso=length(isorange);
  [R.isorange,colors]=fc_graphics4mesh.getisocolors(U,R.isorange,R.color);
  
  R.niso=length(R.isorange); 
  
  PrevHold=fc_tools.graphics.SetHoldOn(true);
  nP=size(P,1);
  h=zeros(nP,R.niso);
  for k=1:nP
    [U,G,J,BC] = fc_tools.graphics.gptoolbox.slice_tets2(q',me',P(k,:));
    if ~isempty(U)
      [LS,LD,I] = fc_tools.graphics.gptoolbox.isolines(U,G,BC*u,R.isorange);
      for i=1:R.niso
        II=find(I==i);
        if isempty(II),h(i)=NaN;else
          N=length(II);
          X=[LS(II,1) LD(II,1) NaN(N,1)]';Y=[LS(II,2) LD(II,2) NaN(N,1)]';Z=[LS(II,3) LD(II,3) NaN(N,1)]';
          h(k,i)=plot3(X(:),Y(:),Z(:),'Tag',sprintf('isovalue : %g',R.isorange(i)),'color',colors(i,:),varargin{:}); 
        end
      end
    end
  end
%    if nargout>=1, varargout{1}=colors;end
%    if nargout>=2, varargout{2}=R.isorange;end
%    if nargout==3, varargout{3}=h;end
%    fc_tools.graphics.RestoreHold(PrevHold)
  fc_tools.graphics.view3D()
  cax=[];
  if R.isocolorbar
    cax=fc_tools.graphics.colorbarIso(colors,R.isorange,R.format);
  end
  if R.mouse && ~fc_tools.comp.isOctave()
    datacursormode on
    dcm = datacursormode(gcf);
    set(dcm,'UpdateFcn',@fc_graphics4mesh.showinfo)
  end
  if nargout>=1, varargout{1}=colors;end
  if nargout>=2, varargout{2}=R.isorange;end
  if nargout>=3, varargout{3}=cax;end
  %if nargout==4, varargout{4}=h;end
  if nargout==4,
    hl=zeros(1,niso); % rustine
    for i=1:R.niso
      [~,j]=ismember(R.isorange(i),isorange);
      hl(j)=h(i);
    end
    %whos hl
    varargout{4}=hl;
  end
  fc_tools.graphics.RestoreHold(PrevHold)
end
