function vers=version(varargin)
% FUNCTION fc_oogmsh.gmsh.version
%   Returns gmsh version as string. 
%
% USAGE:
%   ver=fc_oogmsh.gmsh.version()
%
% TROUBLE:
%
%   On Fedora 29, with error messages
%     * "...gmsh: symbol lookup error: /lib64/libfontconfig.so.1: undefined symbol: FT_Done_MM_Var"
%        Need to start Matlab by preloading /lib64/libfreetype.so.6 library:
%        
%         LD_PRELOAD=/lib64/libfreetype.so.6 /usr/local/MATLAB/R2018a/bin/matlab 
%
%     * "...gmsh: <MATLAB_2016b_DIR>/sys/os/glnxa64/libstdc++.so.6: version `CXXABI_1.3.9' not found (required by /lib64/libGLU.so.1)"
%        Need to start Matlab by preloading /usr/lib64/libstdc++.so.6 library:
%        
%         LD_PRELOAD=/usr/lib64/libstdc++.so.6 /usr/local/MATLAB/R2018a/bin/matlab
%
%     Under Matlab R2016a, the two libraries are required:
%
%         LD_PRELOAD="/lib64/libfreetype.so.6 /usr/lib64/libstdc++.so.6" /usr/local/MATLAB/R2016a/bin/matlab
%
% Copyright (C) 2017-2020 F. Cuvelier
  p = inputParser;
  p.addParamValue('gmsh_bin',fc_oogmsh.gmsh.command(),@ischar);
  p.parse(varargin{:});
  if fc_tools.comp.isOctave() && ispc()
	  vers=getOctavePC(p.Results.gmsh_bin);return;
  end
  [status,result]=system([p.Results.gmsh_bin,' -version 2>&1' ]);
  if status~=0 
    fprintf('Trouble with gmsh command :\n  -> %s\n',p.Results.gmsh_bin);
    if status==20,
      fprintf('Delete <HOME>/.gmshrc file to correct this issue...\n')
    end
    if status==1,
      fprintf('Delete <HOME>/.gmsh-options file to correct this issue...\n')
    end
    error(result);
  end
  I=regexp(result,'\n');
  if numel(I)==1 % old version
    vers=result(1:(I-1));
  else
    vers=result(I(end-1)+1:I(end)-1);
  end
end

function ver=getOctavePC(gmsh_bin)
  % cannot catch output of gmsh.exe --version!
  if exist('version.out')==2,delete('version.out');end
  fid=fopen('version.geo','w');
  fprintf(fid,'Printf("%%g %%g %%g",GMSH_MAJOR_VERSION,GMSH_MINOR_VERSION,GMSH_PATCH_VERSION) > "version.out";');
  fclose(fid);
  [status,result]=system([gmsh_bin,' -2 version.geo -v 2']);
  if status~=0
    fprintf('Trouble when using gmsh in "system" function:\n  -> %s\n',gmsh_bin);
    error(result)
  end
  fid=fopen('version.out','r');
  R=fscanf(fid,'%d',3);
  fclose(fid);
  if exist('version.out')==2,delete('version.out');end
  if exist('version.msh')==2,delete('version.msh');end 
  if exist('version.geo')==2,delete('version.geo');end  
  ver=sprintf('%d.%d.%d',R(1),R(2),R(3));
end
